==> wiki3_4_1.zip: wiki3_4_1/plugin/bbs/BBS2.pm <==
############################################################
#
# ǼƥեϤޤƤڡȤʤꡢڡ⥵ݡȤޤ
# <pre>
# {{bbs2 ǼĤ̾,ɽ}}
# </pre>
# bbsץ饰Ȥΰ㤤ϣƤĤΥڡȤƺ졢
# ɽ뤳ȤǤϻɽ뤿ᡢ
# ˲ưԽɬפޤ
# ɽά10鷺ɽޤ<br>
# <br>
# ǥեȤǤϳƵֿѤΥȥեबϤޤ
# no_commentץĤOFFˤ뤳ȤǤޤ
# <pre>
# {{bbs2 ǼĤ̾,ɽ,no_comment}}
# </pre>
#
############################################################
package plugin::bbs::BBS2;
use strict;
#===========================================================
# 󥹥ȥ饯
#===========================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}


#===========================================================
# Ǽϥե
#===========================================================
sub inline {
	my $self   = shift;
	my $wiki   = shift;
	my $name   = shift;
	my $once   = shift;
	my $option = shift;
	
	if($name eq ""){
		return &Util::error("ǼĤ̾ꤵƤޤ");
	}
	if(!&Util::check_numeric($once)){
		$option = $once;
		$once   = 2;
	}
	
	my $cgi = $wiki->get_CGI;
	my $page = $cgi->param("page");
	
	my $cnt    = $cgi->param("cnt");
	if($cnt eq ""){ $cnt = 0; }
	
	# ϥե
	my $tmpl = HTML::Template->new(filename=>$wiki->config('tmpl_dir')."/bbs.tmpl",
	                               die_on_bad_params=>0);
	
	my $buf = "<form method=\"post\" action=\"".$wiki->config('script_name')."\">\n".
	          $tmpl->output.
	          "<input type=\"hidden\" name=\"action\" value=\"BBS2\">\n".
	          "<input type=\"hidden\" name=\"bbsname\" value=\"".&Util::escapeHTML($name)."\">\n";
	
	if($option eq "no_comment"){
		$buf .="<input type=\"hidden\" name=\"no_comment\" value=\"true\">\n"
	}
	
	$buf .= "</form>";
	
	# ΰϢ
	my $backup_pagename = $cgi->param("page");
	my $i = 0;
	my @list = $self->get_content_list($wiki,$name);
	foreach my $item (@list){
		if($i >= $cnt*$once){
			my $content = $wiki->get_page($item->{name});
			$cgi->param("page",$item->{name});
			$buf .= $wiki->process_wiki($content);
		}
		$i++;
		if($i/$once == $cnt+1){
			last;
		}
	}
	# ڡѤΥ
	$buf .= "<p>[ ";
		my $pagecnt = 1;
		for($i=0;$i<=$#list;$i=$i+$once){
			if($cnt==$pagecnt-1){
				$buf .= $pagecnt." ";
			} else {
				$buf .= "<a href=\"".$wiki->config('script_name')."?page=".&Util::url_encode($page).
				        "&amp;cnt=".($pagecnt-1)."\">".$pagecnt."</a> ";
			}
			$pagecnt++;
		}
		$buf .= "]</p>\n";
	
	$cgi->param("page",$backup_pagename);
	return $buf;
}

#===========================================================
# ΰ
#===========================================================
sub get_content_list {
	my $self = shift;
	my $wiki = shift;
	my $name = shift;
	my @list = ();
	
	foreach my $pagename ($wiki->get_page_list()){
		if($pagename =~ /^BBS-$name\/([0-9]+)$/){
			push(@list,{name=>$pagename,id=>$1});
		}
	}
	@list = sort { $b->{id} <=> $a->{id} } @list;
	return @list;
}

1;

==> wiki3_4_4.zip: wiki3_4_4/plugin/bbs/BBS2.pm <==
############################################################
#
# ǼƥեϤޤƤڡȤʤꡢڡ⥵ݡȤޤ
# <pre>
# {{bbs2 ǼĤ̾,ɽ}}
# </pre>
#
# bbsץ饰Ȥΰ㤤ϣƤĤΥڡȤƺ졢
# ɽ뤳ȤǤϻɽ뤿ᡢ
# ˲ưԽɬפޤ
# ɽά10鷺ɽޤ<br>
# <br>
# ǥեȤǤϳƵֿѤΥȥեबϤޤ
# no_commentץĤOFFˤ뤳ȤǤޤ
# <pre>
# {{bbs2 ǼĤ̾,ɽ,no_comment}}
# </pre>
#
# reverse_commentץĤȳƵˤĤcommentץ饰
# reverseץĤ뤳ȤǤȤɽ褦ˤʤޤ
# <pre>
# {{bbs2 ǼĤ̾,ɽ,reverse_comment}}
# </pre>
#
############################################################
package plugin::bbs::BBS2;
#use strict;
#===========================================================
# 󥹥ȥ饯
#===========================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}


#===========================================================
# Ǽϥե
#===========================================================
sub inline {
	my $self   = shift;
	my $wiki   = shift;
	my $name   = shift;
	my $once   = shift;
	my $option = shift;
	
	if($name eq ""){
		return &Util::error("ǼĤ̾ꤵƤޤ");
	}
	if(!&Util::check_numeric($once)){
		$option = $once;
		$once   = 2;
	}
	
	my $cgi = $wiki->get_CGI;
	my $page = $cgi->param("page");
	
	my $cnt    = $cgi->param("cnt");
	if($cnt eq ""){ $cnt = 0; }
	
	# ϥե
	my $tmpl = HTML::Template->new(filename=>$wiki->config('tmpl_dir')."/bbs.tmpl",
	                               die_on_bad_params=>0);
	
	# ̾
	my $postname = $cgi->cookie(-name=>'post_name');
	if($postname eq ''){
		my $login = $wiki->get_login_info();
		if(defined($login)){
			$postname = $login->{id};
		}
	}
	$tmpl->param(NAME=>$postname);
	
	my $buf = "<form method=\"post\" action=\"".$wiki->config('script_name')."\">\n".
	          $tmpl->output.
	          "<input type=\"hidden\" name=\"action\" value=\"BBS2\">\n".
	          "<input type=\"hidden\" name=\"bbsname\" value=\"".&Util::escapeHTML($name)."\">\n";
	
	if($option eq "no_comment"){
		$buf .="<input type=\"hidden\" name=\"option\" value=\"no_comment\">\n";
	} elsif($option eq "reverse_comment"){
		$buf .="<input type=\"hidden\" name=\"option\" value=\"reverse_comment\">\n";
	}
	
	$buf .= "</form>";
	
	# ΰϢ
#	my $backup_pagename = $cgi->param("page");
	my $i = 0;
	my @list = $self->get_content_list($wiki,$name);
	foreach my $item (@list){
		if($i >= $cnt*$once){
			$buf .= $wiki->process_wiki("{{include ".$item->{name}."}}\n");
#			my $content = $wiki->get_page($item->{name});
#			$cgi->param("page",$item->{name});
#			$buf .= $wiki->process_wiki($content);
		}
		$i++;
		if($i/$once == $cnt+1){
			last;
		}
	}
	# ڡѤΥ
	$buf .= "<p>[ ";
		my $pagecnt = 1;
		for($i=0;$i<=$#list;$i=$i+$once){
			if($cnt==$pagecnt-1){
				$buf .= $pagecnt." ";
			} else {
				$buf .= "<a href=\"".$wiki->config('script_name')."?page=".&Util::url_encode($page).
				        "&amp;cnt=".($pagecnt-1)."\">".$pagecnt."</a> ";
			}
			$pagecnt++;
		}
		$buf .= "]</p>\n";
	
#	$cgi->param("page",$backup_pagename);
	return $buf;
}

#===========================================================
# ΰ
#===========================================================
sub get_content_list {
	my $self = shift;
	my $wiki = shift;
	my $name = shift;
	my @list = ();
	
	foreach my $pagename ($wiki->get_page_list()){
		if($pagename =~ /^BBS-$name\/([0-9]+)$/){
			push(@list,{name=>$pagename,id=>$1});
		}
	}
	@list = sort { $b->{id} <=> $a->{id} } @list;
	return @list;
}

1;
